import React, { useState, useEffect, useCallback } from 'react'
import { Input, AutoComplete, message, Popover, Select } from 'antd'
import { searchAdress, placeAroundRelay } from '../../../../apis/process'
import { debounce, lngmkt, isObject, mercatorToLngLat, isJson } from '../../../../utils/index'
import { request } from '@wisdom-utils/utils'
const SearchLocation = (props) => {

  const areaName = window?.globalConfig?.mapsettings?.areasettings?.areaName || ''
  const { value, onChange, schema, addons } = props
  const { disabled, placeholder, presetValue, coordSync } = schema
  const [options, setOptions] = useState([])

  const getAdress = async (value) => {
    let postStr = {
      "keyWord": value,
      "queryType": 12,
      "start": 0,
      "count": 10,
      specify: areaName,
    }
    const { code, data } = await placeAroundRelay(`http://api.tianditu.gov.cn/v2/search?postStr=${JSON.stringify(postStr)}&type=query&tk=a1d480f55b805db96e1ed295e62c72b1`)
    if (code === '0' && isJson(data)) {
      let res = JSON.parse(data) || {}
      setOptions(res.pois || [])
    } else {
      message.error('请求失败!')
    }
  }

  const onSearch = async (value) => {
    getAdress(value)
  }

  const handleSearch = (value) => {
    onChange(value)
  }

  const onSelect = (value) => {
    let location = options.find(v => v.name === value)?.lonlat
    if (location) {
      let array = location.split(',')
      let coord = lngmkt({ lng: array[0], lat: array[1] })
      if (coordSync) {
        let paths = Object.keys(addons.formData)
        let targetPath = null
        if (Array.isArray(paths)) {
          paths.forEach(v => {
            let values = addons.getValue(v)
            if (isObject(values)) {
              for (let key in values) {
                if (key === coordSync) {
                  targetPath = `${v}.${key}`
                }
              }
            }
          })
        }
        if (targetPath) {
          addons.setValue(targetPath, `${coord.x}, ${coord.y}`)
        }
      }
    }
    onChange(value)
  }

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue || '')
    }
  }, [presetValue])

  return (
    <AutoComplete
      style={{ width: '100%' }}
      options={(options || []).map(v => ({ label: v.name, value: v.name }))}
      onSelect={onSelect}
      onSearch={handleSearch}
      disabled={disabled}
      value={value}
    >
      <Input.Search
        placeholder={disabled ? (placeholder || '') : (placeholder || '请输入地址点击搜索或者回车')}
        enterButton
        onSearch={onSearch}
      />
    </AutoComplete>
  )
}

export default SearchLocation
